@@ -14,9 +14,9 @@
 #include "incidencechanger.h"
 #include "itiphandlerhelper_p.h"
 
-#include <collection.h>
-#include <item.h>
-#include <transactionsequence.h>
+#include <Akonadi/Collection>
+#include <Akonadi/Item>
+#include <Akonadi/TransactionSequence>
 
 #include <QObject>
 #include <QPointer>
@@ -51,7 +51,7 @@ public:
     {
     }
 
-    virtual ~Change()
+    ~Change() override
     {
         if (parentChange) {
             parentChange->childAboutToDie(this);
@@ -178,7 +178,7 @@ public:
     QString m_description;
     bool m_transactionCompleted;
 
-    AtomicOperation(IncidenceChanger::Private *icp, uint ident);
+    AtomicOperation(IncidenceChangerPrivate *icp, uint ident);
 
     ~AtomicOperation()
     {
@@ -187,7 +187,7 @@ public:
             for (int i = 0; i < m_changes.count(); ++i) {
                 // When a job that can finish successfully is aborted because the transaction failed
                 // because of some other job, akonadi is returning an Unknown error
-                // which isnt very specific
+                // which isn't very specific
                 if (m_changes[i]->completed
                     && (m_changes[i]->resultCode == IncidenceChanger::ResultCodeSuccess
                         || (m_changes[i]->resultCode == IncidenceChanger::ResultCodeJobError
@@ -239,15 +239,15 @@ private:
     QVector<Change::Ptr> m_changes;
     bool m_wasRolledback = false;
     Akonadi::TransactionSequence *m_transaction = nullptr; // constructed in first use
-    IncidenceChanger::Private *m_incidenceChangerPrivate = nullptr;
+    IncidenceChangerPrivate *m_incidenceChangerPrivate = nullptr;
 };
 
-class Q_DECL_HIDDEN IncidenceChanger::Private : public QObject
+class IncidenceChangerPrivate : public QObject
 {
     Q_OBJECT
 public:
-    explicit Private(bool enableHistory, ITIPHandlerComponentFactory *factory, IncidenceChanger *mIncidenceChanger);
-    ~Private();
+    explicit IncidenceChangerPrivate(bool enableHistory, ITIPHandlerComponentFactory *factory, IncidenceChanger *mIncidenceChanger);
+    ~IncidenceChangerPrivate() override;
 
     void loadCollections(); // async-loading of list of writable collections
     bool isLoadingCollections() const;
@@ -301,7 +301,7 @@ public:
     bool mShowDialogsOnError = false;
     Akonadi::Collection mDefaultCollection;
     Akonadi::EntityTreeModel *mEntityTreeModel = nullptr;
-    DestinationPolicy mDestinationPolicy;
+    IncidenceChanger::DestinationPolicy mDestinationPolicy;
     QVector<Akonadi::Item::Id> mDeletedItemIds;
     Change::List mPendingCreations; // Creations waiting for collections to be loaded
 
