@@ -10,11 +10,13 @@
 
 #include "akonadi-calendar_export.h"
 
-#include <AkonadiWidgets/StandardActionManager>
-#include <kcalendarcore/todo.h>
+#include <Akonadi/StandardActionManager>
+#include <KCalendarCore/Todo>
 
 #include <QObject>
 
+#include <memory>
+
 // needed for windows ce, its defined somewhere
 #undef CreateEvent
 
@@ -26,6 +28,8 @@ class QWidget;
 namespace Akonadi
 {
 class Item;
+class StandardCalendarActionManagerPrivate;
+
 /**
  * @short Manages calendar specific actions for collection and item views.
  *
@@ -59,7 +63,7 @@ public:
     /**
      * Destroys the standard calendar action manager.
      */
-    ~StandardCalendarActionManager();
+    ~StandardCalendarActionManager() override;
 
     /**
      * Sets the collection selection model based on which the collection
@@ -175,8 +179,7 @@ Q_SIGNALS:
 
 private:
     //@cond PRIVATE
-    class Private;
-    Private *const d;
+    std::unique_ptr<StandardCalendarActionManagerPrivate> const d;
     //@endcond
 };
 }
